Class: PrayRemote::StdoeWrapper
- Includes:
- DRab::DRabUndumped
- Defined in:
- lib/pray-remote/pray-remote.rb
Instance Method Summary collapse
- #<<(data) ⇒ Object
- #eof? ⇒ Boolean
- #flush ⇒ Object
-
#initialize(o) ⇒ StdoeWrapper
constructor
A new instance of StdoeWrapper.
- #print(*args) ⇒ Object
- #printf(*args) ⇒ Object
- #puts(*lines) ⇒ Object
- #respond_to?(*args) ⇒ Boolean
-
#tty? ⇒ Boolean
Some versions of Pry expect $stdout or its output objects to respond to this message.
- #write(*args) ⇒ Object
Constructor Details
#initialize(o) ⇒ StdoeWrapper
Returns a new instance of StdoeWrapper.
27 28 29 |
# File 'lib/pray-remote/pray-remote.rb', line 27 def initialize(o) @stdoe = o end |
Instance Method Details
#<<(data) ⇒ Object
66 67 68 69 |
# File 'lib/pray-remote/pray-remote.rb', line 66 def <<(data) @stdoe << data self end |
#eof? ⇒ Boolean
54 55 56 |
# File 'lib/pray-remote/pray-remote.rb', line 54 def eof? @stdoe.eof? end |
#flush ⇒ Object
42 43 44 |
# File 'lib/pray-remote/pray-remote.rb', line 42 def flush @stdoe.flush end |
#print(*args) ⇒ Object
50 51 52 |
# File 'lib/pray-remote/pray-remote.rb', line 50 def print(*args) @stdoe.print(*args) end |
#printf(*args) ⇒ Object
62 63 64 |
# File 'lib/pray-remote/pray-remote.rb', line 62 def printf(*args) @stdoe.printf(*args) end |
#puts(*lines) ⇒ Object
58 59 60 |
# File 'lib/pray-remote/pray-remote.rb', line 58 def puts(*lines) @stdoe.puts(*lines) end |
#respond_to?(*args) ⇒ Boolean
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/pray-remote/pray-remote.rb', line 31 def respond_to?(*args) case args[0] when :_dump true when :marshal_dump false else @stdoe.respond_to?(*args) end end |
#tty? ⇒ Boolean
Some versions of Pry expect $stdout or its output objects to respond to this message.
73 74 75 |
# File 'lib/pray-remote/pray-remote.rb', line 73 def tty? false end |
#write(*args) ⇒ Object
46 47 48 |
# File 'lib/pray-remote/pray-remote.rb', line 46 def write(*args) @stdoe.write(*args) end |