Class: PrayRemote::Client
- Includes:
- DRab::DRabUndumped
- Defined in:
- lib/pray-remote/pray-remote.rb
Overview
A client is used to retrieve information from the client program.
Instance Attribute Summary collapse
-
#editor ⇒ Object
Returns the value of attribute editor.
-
#input ⇒ Object
Returns the value of attribute input.
-
#mypry ⇒ Object
Returns the value of attribute mypry.
-
#output ⇒ Object
Returns the value of attribute output.
-
#stderr ⇒ Object
Returns the value of attribute stderr.
-
#stdout ⇒ Object
Returns the value of attribute stdout.
-
#thread ⇒ Object
Returns the value of attribute thread.
Instance Method Summary collapse
-
#input_proxy ⇒ InputProxy
Proxy for the input.
-
#kill ⇒ Object
Tells the client the session is terminated.
-
#wait ⇒ Object
Waits until both an input and output are set.
Instance Attribute Details
#editor ⇒ Object
Returns the value of attribute editor
228 229 230 |
# File 'lib/pray-remote/pray-remote.rb', line 228 def editor @editor end |
#input ⇒ Object
Returns the value of attribute input
228 229 230 |
# File 'lib/pray-remote/pray-remote.rb', line 228 def input @input end |
#mypry ⇒ Object
Returns the value of attribute mypry
228 229 230 |
# File 'lib/pray-remote/pray-remote.rb', line 228 def mypry @mypry end |
#output ⇒ Object
Returns the value of attribute output
228 229 230 |
# File 'lib/pray-remote/pray-remote.rb', line 228 def output @output end |
#stderr ⇒ Object
Returns the value of attribute stderr
228 229 230 |
# File 'lib/pray-remote/pray-remote.rb', line 228 def stderr @stderr end |
#stdout ⇒ Object
Returns the value of attribute stdout
228 229 230 |
# File 'lib/pray-remote/pray-remote.rb', line 228 def stdout @stdout end |
#thread ⇒ Object
Returns the value of attribute thread
228 229 230 |
# File 'lib/pray-remote/pray-remote.rb', line 228 def thread @thread end |
Instance Method Details
#input_proxy ⇒ InputProxy
Returns Proxy for the input.
249 250 251 |
# File 'lib/pray-remote/pray-remote.rb', line 249 def input_proxy InputProxy.new input end |
#kill ⇒ Object
Tells the client the session is terminated
244 245 246 |
# File 'lib/pray-remote/pray-remote.rb', line 244 def kill thread.run if not thread.nil? end |
#wait ⇒ Object
Waits until both an input and output are set
239 240 241 |
# File 'lib/pray-remote/pray-remote.rb', line 239 def wait sleep 0.01 until input and output and thread end |